# Swagger\Client\OrdersApi

All URIs are relative to *https://api.ingrammicro.com:443/sandbox/resellers/v5*

Method | HTTP request | Description
------------- | ------------- | -------------
[**deleteOrdersOrderNumber**](OrdersApi.md#deleteordersordernumber) | **DELETE** /orders/{ordernumber} | Cancel an existing order
[**getOrdersSearch**](OrdersApi.md#getorderssearch) | **GET** /orders/search | Search Your Orders
[**getV5OrdersDetails**](OrdersApi.md#getv5ordersdetails) | **GET** /orders/{ordernumber} | Get order details
[**postV5OrdersCreate**](OrdersApi.md#postv5orderscreate) | **POST** /orders | Create a new order

# **deleteOrdersOrderNumber**
> \Swagger\Client\Model\OrderCancelResponse deleteOrdersOrderNumber($ordernumber, $customer_number, $iso_country_code, $entry_date)

Cancel an existing order

A request to cancel a previously accepted order, this call must be submitted before the order is released to Ingram Micro’s warehouse.    The order cannot be canceled once it is released to the warehouse.  *Direct ship orders cannot be canceled.  Contact your sales rep for assistance.  *NOTE: orderNumber, isoCountryCode, customerNumber and entryDate is mandatory.*

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure OAuth2 access token for authorization: application
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setAccessToken('YOUR_ACCESS_TOKEN');

$apiInstance = new Swagger\Client\Api\OrdersApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$ordernumber = "ordernumber_example"; // string | Ingram Micro sales order number
$customer_number = "customer_number_example"; // string | Your unique Ingram Micro customer number
$iso_country_code = "iso_country_code_example"; // string | 2 chars ISO country code
$entry_date = "2020-04-03"; // string | Order entry date (yyyy-mm-dd)

try {
    $result = $apiInstance->deleteOrdersOrderNumber($ordernumber, $customer_number, $iso_country_code, $entry_date);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling OrdersApi->deleteOrdersOrderNumber: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ordernumber** | **string**| Ingram Micro sales order number |
 **customer_number** | **string**| Your unique Ingram Micro customer number |
 **iso_country_code** | **string**| 2 chars ISO country code |
 **entry_date** | **string**| Order entry date (yyyy-mm-dd) | [default to 2020-04-03]

### Return type

[**\Swagger\Client\Model\OrderCancelResponse**](../Model/OrderCancelResponse.md)

### Authorization

[application](../../README.md#application)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getOrdersSearch**
> \Swagger\Client\Model\OrderSearchResponse getOrdersSearch($customer_number, $isocountrycode, $ordernumber, $customerordernumber, $orderstatus, $startcreatetimestamp, $endcreatetimestamp, $pagesize, $pagenumber)

Search Your Orders

Easy to use, and implement order search API endpoint with the capability to search using various parameters, supports pagination. Search using any or all of the parameters below- 1. ordernumber - Ingram Micro sales order number 2. customerordernumber - The PO or order number provided by you when creating an order 3. orderstatus - user order status codes for the search, default is set to \"any\" 4. startcreatetimestamp and endcreatetimestamp - Order create date range  For pagination please use following parameters -  1. pagesize - default 25, max 100 2. pagenumber - default 1  Search mechanism -  1. If no search or filter criteria provided then records are returnedin descending order of creation 2. If all the search parameters are provided then all of them are used for search  Order Status values -  P - PENDING                       R - RELEASED                      4 - SHIPPED                       I - INVOICED                    V - VOIDED                       The search endpoint also return HATEOAS links for order details and invoice details if applicable.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure OAuth2 access token for authorization: application
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setAccessToken('YOUR_ACCESS_TOKEN');

$apiInstance = new Swagger\Client\Api\OrdersApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$customer_number = "customer_number_example"; // string | Your unique Ingram Micro customer number
$isocountrycode = "isocountrycode_example"; // string | 2 char iso country code
$ordernumber = "ordernumber_example"; // string | Ingram sales order number
$customerordernumber = "customerordernumber_example"; // string | Search using your PO/Order number
$orderstatus = "any"; // string | Ingram Micro order status
$startcreatetimestamp = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | Search start date/time in UTC format
$endcreatetimestamp = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | Search end date/time in UTC format
$pagesize = 56; // int | Number of records required in the call
$pagenumber = 1; // int | the page number reference

try {
    $result = $apiInstance->getOrdersSearch($customer_number, $isocountrycode, $ordernumber, $customerordernumber, $orderstatus, $startcreatetimestamp, $endcreatetimestamp, $pagesize, $pagenumber);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling OrdersApi->getOrdersSearch: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **customer_number** | **string**| Your unique Ingram Micro customer number |
 **isocountrycode** | **string**| 2 char iso country code |
 **ordernumber** | **string**| Ingram sales order number | [optional]
 **customerordernumber** | **string**| Search using your PO/Order number | [optional]
 **orderstatus** | **string**| Ingram Micro order status | [optional] [default to any]
 **startcreatetimestamp** | **\DateTime**| Search start date/time in UTC format | [optional]
 **endcreatetimestamp** | **\DateTime**| Search end date/time in UTC format | [optional]
 **pagesize** | **int**| Number of records required in the call | [optional]
 **pagenumber** | **int**| the page number reference | [optional] [default to 1]

### Return type

[**\Swagger\Client\Model\OrderSearchResponse**](../Model/OrderSearchResponse.md)

### Authorization

[application](../../README.md#application)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getV5OrdersDetails**
> \Swagger\Client\Model\OrderDetailResponse getV5OrdersDetails($ordernumber, $customernumber, $isocountrycode, $customerordernumber, $startcreatetimestamp, $endcreatetimestamp)

Get order details

Retrieve details of an existing order using Ingram Micro sales order number. The sales order number is returned in the order create POST response.   It is highly recommended that you store the IM sales order number. You can also retrieve the IM sales order number by searching your existing order using various parameters including customer PO/order number provided by you at the time of creating the order.  In case the IM sales order number is repeated, you can refine the result by providing customerordernumber for additional filtering and/or using the date range to filter on order creation date.   *NOTE: ordernumber, isocountrycode and customernumber is mandatory.*

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure OAuth2 access token for authorization: application
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setAccessToken('YOUR_ACCESS_TOKEN');

$apiInstance = new Swagger\Client\Api\OrdersApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$ordernumber = "ordernumber_example"; // string | Ingram Micro sales order number
$customernumber = "20-222222"; // string | Your unique Ingram Micro customer number
$isocountrycode = "US"; // string | 2 chars ISO country code
$customerordernumber = "customerordernumber_example"; // string | Your PO/Order Number provide at the time of order creation
$startcreatetimestamp = new \DateTime("2013-10-20"); // \DateTime | Filter start date - format YYYY-MM-DD
$endcreatetimestamp = "endcreatetimestamp_example"; // string | Filter end date - format YYYY-MM-DD

try {
    $result = $apiInstance->getV5OrdersDetails($ordernumber, $customernumber, $isocountrycode, $customerordernumber, $startcreatetimestamp, $endcreatetimestamp);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling OrdersApi->getV5OrdersDetails: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ordernumber** | **string**| Ingram Micro sales order number |
 **customernumber** | **string**| Your unique Ingram Micro customer number | [default to 20-222222]
 **isocountrycode** | **string**| 2 chars ISO country code | [default to US]
 **customerordernumber** | **string**| Your PO/Order Number provide at the time of order creation | [optional]
 **startcreatetimestamp** | **\DateTime**| Filter start date - format YYYY-MM-DD | [optional]
 **endcreatetimestamp** | **string**| Filter end date - format YYYY-MM-DD | [optional]

### Return type

[**\Swagger\Client\Model\OrderDetailResponse**](../Model/OrderDetailResponse.md)

### Authorization

[application](../../README.md#application)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **postV5OrdersCreate**
> \Swagger\Client\Model\OrderCreateResponse postV5OrdersCreate($body)

Create a new order

Use POST order create API for instant ordering with Ingram Micro. The API supports stocked SKUs as well as licensing and warranties SKUs. It is highly recommended to provide \"ingrampartnumber\" for the SKUs.  For using vendorpartnumber to place the orders, please use the product search endpoint to find the ingrampartnumber for a specific vendorpartnumber and then supply the ingrampartnumber to place an order.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure OAuth2 access token for authorization: application
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setAccessToken('YOUR_ACCESS_TOKEN');

$apiInstance = new Swagger\Client\Api\OrdersApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$body = new \Swagger\Client\Model\OrderCreateRequest(); // \Swagger\Client\Model\OrderCreateRequest | 

try {
    $result = $apiInstance->postV5OrdersCreate($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling OrdersApi->postV5OrdersCreate: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\Swagger\Client\Model\OrderCreateRequest**](../Model/OrderCreateRequest.md)|  | [optional]

### Return type

[**\Swagger\Client\Model\OrderCreateResponse**](../Model/OrderCreateResponse.md)

### Authorization

[application](../../README.md#application)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

